from sqlalchemy import *
from migrate import *
import migrate.changeset
try:
    from sqlalchemy.dialects.mssql.pyodbc import MSDialect_pyodbc
except:
    from sqlalchemy.databases.mssql import MSSQLDialect_pyodbc as MSDialect_pyodbc
from dictionaries.versions import views_helper

def getCardTables(meta):
    card1 = Table('card1', meta, autoload=True)
    card2 = Table('card2', meta, autoload=True)
    return [card1, card2]

def getTables(meta):
    client1 = Table('client1', meta, autoload=True)
    client2 = Table('client2', meta, autoload=True)
    dept1 = Table('dept1', meta, autoload=True)
    dept2 = Table('dept2', meta, autoload=True)
    return getCardTables(meta) + [client1, client2, dept1, dept2]

def setIndex(migrate_engine, col, tbl, index_name):
    if type(migrate_engine.connect().dialect) is MSDialect_pyodbc:
        col.result_column.table = tbl
        ind = Index(index_name, col.result_column, unique=False)
        ind.create()
      
def setPrimaryKeyConstraint(migrate_engine, col, tbl):
    if type(migrate_engine.connect().dialect) is MSDialect_pyodbc:
        col.result_column.table = tbl
        const = migrate.changeset.constraint.PrimaryKeyConstraint(col.result_column, name = 'pk_%s' % tbl.name)
        const.create()

def upgrade(migrate_engine):
    meta = MetaData(bind = migrate_engine)
    # Upgrade operations go here. Don't create your own engine; use the engine
    # named 'migrate_engine' imported from migrate.
    for tbl in getCardTables(meta):
        col = tbl.c.idcard.alter(type=String(100))
        setPrimaryKeyConstraint(migrate_engine, col, tbl)
    for tbl in getTables(meta):
        col = tbl.c.idclient.alter(type=String(100))
        if tbl.name[:-1] == 'card':
            setIndex(migrate_engine, col, tbl, 'cardidclient')
        if tbl.name[:-1] == 'client':
            setPrimaryKeyConstraint(migrate_engine, col, tbl)
    for name in ['card', 'client', 'dept']:
        views_helper.update_dic_view(migrate_engine, name)
        

def downgrade(migrate_engine):
    meta = MetaData(bind = migrate_engine)
    # Operations to reverse the above upgrade go here.
    conn = migrate_engine.connect()
    for tbl in getTables(meta):
        if tbl.name[:-1] == 'client':
            col = tbl.c.idclient.alter(type=Integer, autoincrement=True)
            setPrimaryKeyConstraint(migrate_engine, col, tbl)
        else:
            col = tbl.c.idclient.alter(type=Integer)
            if tbl.name[:-1] == 'card':
                setIndex(migrate_engine, col, tbl, 'cardidclient')
    for tbl in getCardTables(meta):
        col = tbl.c.idcard.alter(type=Integer, autoincrement=True)
        setPrimaryKeyConstraint(migrate_engine, col, tbl)
    for name in ['card', 'client', 'dept']:
        views_helper.update_dic_view(migrate_engine, name)
