from sqlalchemy import *
from migrate import *
import migrate.changeset

def getIndexes(meta):
    carditem = Table('carditem', meta, autoload=True)
    crights = Table('crights', meta, autoload=True)
    discitem = Table('discitem', meta, autoload=True)
    document = Table('document', meta, autoload=True)
    goodsitem = Table('goodsitem', meta, autoload=True)
    moneyitem = Table('moneyitem', meta, autoload=True)
    stornogoodsitem = Table('stornogoodsitem', meta, autoload=True)
    workshift = Table('workshift', meta, autoload=True)
    
    carditemIndices = [
        Index('carditemnumber', carditem.c.number, unique=False),
        Index('carditemidcard', carditem.c.idcard, unique=False),
        Index('carditemidcardgroup', carditem.c.idcardgroup, unique=False),
        Index('carditemidclient', carditem.c.idclient, unique=False)
    ]
    
    crightsIndices = [
        Index('crightscashiercard', crights.c.cashiercard, unique=False),
        Index('crightsactorcard', crights.c.actorcard, unique=False),
        Index('crightsopcode', crights.c.opcode, unique=False),
        Index('crightsoptime', crights.c.optime, unique=False)
    ]
    
    discitemIndices = [
        Index('discitemcardnumber', discitem.c.cardnumber, unique=False),
        Index('discitemdisccode', discitem.c.disccode, unique=False),
        Index('discitemdiscscheme', discitem.c.discscheme, unique=False),
        Index('discitemdtime', discitem.c.dtime, unique=False)
    ]
    
    documentIndices = [
        Index('documentchecknum', document.c.checknum, unique=False),
        Index('dcoumentdoctype', document.c.doctype, unique=False),
        Index('documentdept', document.c.dept, unique=False),
        Index('documentscode', document.c.scode, unique=False),
        Index('documentopid', document.c.opid, unique=False),
        Index('documenttime_beg', document.c.time_beg, unique=False),
        Index('documenttime_end', document.c.time_end, unique=False)
    ]
    
    goodsitemIndices = [
        Index('goodsitemdeptcode', goodsitem.c.deptcode, unique=False),
        Index('goodsitemscode', goodsitem.c.scode, unique=False),
        Index('goodsitemopcode', goodsitem.c.opcode, unique=False),
        Index('goodsitembcode', goodsitem.c.bcode, unique=False),
        Index('goodsitemfrnum', goodsitem.c.frnum, unique=False),
        Index('goodsitemopid', goodsitem.c.opid, unique=False),
        Index('goodsitemttime', goodsitem.c.ttime, unique=False)
    ]
    
    moneyitemIndices = [
        Index('moneyitemscode', moneyitem.c.scode, unique=False),
        Index('moneyitemopcode', moneyitem.c.opcode, unique=False),
        Index('moneyitemfrnum', moneyitem.c.frnum, unique=False),
        Index('moneyitemmtime', moneyitem.c.mtime, unique=False)
    ]
    
    stornogoodsitemIndices = [
        Index('stornogoodsitemdeptcode', stornogoodsitem.c.deptcode, unique=False),
        Index('stornogoodsitemscode', stornogoodsitem.c.scode, unique=False),
        Index('stornogoodsitemopcode', stornogoodsitem.c.opcode, unique=False),
        Index('stornogoodsitembcode', stornogoodsitem.c.bcode, unique=False),
        Index('stornogoodsitemfrnum', stornogoodsitem.c.frnum, unique=False),
        Index('stornogoodsitemopid', stornogoodsitem.c.opid, unique=False),
        Index('stornogoodsitemtimestorno', stornogoodsitem.c.timestorno, unique=False)
    ]
    
    workshiftIndices = [
        Index('workshiftshiftnum', workshift.c.shiftnum, unique=False),
        Index('workshiftcashcode', workshift.c.cashcode, unique=False),
        Index('workshiftscode', workshift.c.scode, unique=False),
        Index('workshifttime_beg', workshift.c.time_beg, unique=False),
        Index('workshifttime_end', workshift.c.time_end, unique=False)
    ]
    
    groups = [ carditemIndices, crightsIndices, discitemIndices, documentIndices, goodsitemIndices, moneyitemIndices, stornogoodsitemIndices, workshiftIndices ]
    return groups

def upgrade(migrate_engine):
    meta = MetaData(bind = migrate_engine)
    # Upgrade operations go here. Don't create your own engine; use the engine
    # named 'migrate_engine' imported from migrate.
    for group in getIndexes(meta):
        for idx in group:
            idx.create()

def downgrade(migrate_engine):
    meta = MetaData(bind = migrate_engine)
    # Operations to reverse the above upgrade go here.
    for group in getIndexes(meta):
        for idx in group:
            idx.drop()
