# -*- coding: utf-8 -*-

from documents.versions import conf
import datetime, time
from documents.versions import dump
import pymysql as mysql
import os
import sys
from artix.database.info import DBInfo

lockFileDir = '/tmp/restoreLock/'
flagRestoreBackgroundFile = os.path.join(lockFileDir, 'restore_background.lck')

if not os.path.exists(lockFileDir):
    os.makedirs(lockFileDir)

def isEmptyTable(cursor, tableName):
    return not cursor.execute("SELECT 1 FROM documents.%s LIMIT 1;" % tableName)

def dropTable(cursor, tableName):
    if isEmptyTable(cursor, tableName):
        cursor.execute("DROP TABLE documents.%s;" % tableName)
        cursor.execute('COMMIT;')
        log_info('drop empty table: %s' % (tableName))
        
def getColumnNames(cursor, tableName):
    q = "SELECT column_name FROM information_schema.columns WHERE table_name = '%s' and table_schema = 'documents' ORDER  BY ordinal_position;" % tableName
    cursor.execute(q)
    return ["`%s`" % (k[0]) for k in cursor.fetchall()]

def log_info(line):
    try:
        with open('/linuxcash/logs/current/artix_restore_data.log', 'a') as f:
            tmpLine = '%s: %s\n' % (datetime.datetime.now(), line)
            f.write(tmpLine)
    except Exception as e:
        print(str(e))

def restoreTable(cursor, tableName, restoreInterval):
    log_info('restore table %s' % (tableName))

    backupTable = "backup_%s" % tableName

    for table in (tableName, backupTable):
        if not dump.isExistTable(cursor, table):
            log_info('Warning! Table %s not found' % (table))
            return

    columns = ','.join(getColumnNames(cursor, backupTable))

    while not isEmptyTable(cursor, backupTable):
        t0 = time.time()
        cursor.execute('START TRANSACTION;')
        cursor.execute("REPLACE documents.%s (%s) select %s from documents.%s limit 1000;" % (tableName, columns, columns, backupTable))
        cursor.execute("DELETE FROM documents.%s limit 1000;" % (backupTable))
        cursor.execute('COMMIT;')

        log_info("load data from %s (<=1000 rows): %s" % (backupTable, format(time.time() - t0, "0.5f")))
        time.sleep(restoreInterval)

    dropTable(cursor, backupTable)

def main():
    try:
        if not os.path.isfile(dump.flagRestoreFile):
            return

        if os.path.isfile(flagRestoreBackgroundFile):
            log_info('find file: %s' % (flagRestoreBackgroundFile))
            log_info('restore data already running')
            return

        restoreInterval = sys.argv[1] if len(sys.argv) > 1 else conf.restoreInterval
        log_info('restore interval = %s' % restoreInterval)

        open(flagRestoreBackgroundFile, 'a').close()
        dbInfo = DBInfo()
        db = mysql.connect(host=dbInfo.host, port=dbInfo.port, user=dbInfo.user, password=dbInfo.password, db="documents")
        db.autocommit(False)
        cur = db.cursor()
        cur.execute('SET foreign_key_checks = 0;')
        cur.execute('SET @TRIGGER_AFTER_INSERT = FALSE;')

        for tableName in dump.getDocTables(cur):
            restoreTable(cur, tableName, int(restoreInterval))

        db.commit()
        cur.close()
        db.close()

        dump.removeFile(dump.flagRestoreFile)
        dump.removeFile(flagRestoreBackgroundFile)

    except Exception as e:
        log_info(str(e))
        raise

if __name__ == "__main__":
    main()
